# Change Log

## [0.1.0](https://pypi.org/project/steadysun/0.1.0) (2024-12-16)

1th release of the steadysun package with basic features.

- **ADD** Forecast Module with simple get_forecast function
- **ADD** PVSystem Class and Model with basic parameters and functions (+ expertParameters)
- **ADD** Documentation with Sphinx/readthedoc (available at: https://steadysun-pypi.readthedocs.io)
